<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>Data::SyncthingConnection</name>
    <message>
        <location filename="../syncthingconnection.cpp" line="181"/>
        <source>disconnected</source>
        <translation>odpojeno</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="183"/>
        <source>reconnecting</source>
        <translation>znovu se připojuje</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="185"/>
        <source>connected</source>
        <translation>spojeno</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="187"/>
        <source>connected, scanning</source>
        <translation>spojeno, skenování</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="189"/>
        <source>connected, paused</source>
        <translation>spojeno, pozastaveno</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="191"/>
        <source>connected, synchronizing</source>
        <translation>spojeno, synchronizuje se</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="193"/>
        <source>connected, remote not in sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="195"/>
        <source>connected, but all remote devices disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="950"/>
        <source>Unable to parse timestamp &quot;%1&quot; (%2): %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>connected, out of sync</source>
        <translation type="vanished">spojeno, nesesynchronizováno</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="197"/>
        <source>unknown</source>
        <translation>neznámý stav spojení</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="472"/>
        <source>Connection configuration is insufficient.</source>
        <translation>Nastavení spojení není dostačující.</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="557"/>
        <source>Unable to rescan: No folder ID specified.</source>
        <translation>Nedaří se znovu prohledat: nezadán žádný identifikátor adresáře.</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="374"/>
        <source>Unable to pause/resume a devices when not connected</source>
        <translation>Nedaří se pozastavit/pokračovat zařízení, když není spojeno</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="489"/>
        <source>Unable to pause/resume a folders when not connected</source>
        <translation>Nedaří se pozastavit/pokračovat složky, když není spojeno</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1517"/>
        <source>Unable to request QR-Code: </source>
        <translation>Nedaří se vyžádat QR kód: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1550"/>
        <source>Unable to parse Syncthing log: </source>
        <translation>Nedaří se zpracovat záznam událostí v Syncthing: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1567"/>
        <source>Unable to request Syncthing log: </source>
        <translation>Nedaří se vyžádat si záznamy událostí v Syncthing: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1019"/>
        <source>Unable to locate certificate used by Syncthing.</source>
        <translation>Nedaří se nalézt certifikát, používaný Syncthing.</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1025"/>
        <source>Unable to load certificate used by Syncthing.</source>
        <translation>Nedaří se načíst certifikát, používaný Syncthing.</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="716"/>
        <source>Unable to parse Syncthing config: </source>
        <translation>Nedaří se zpracovat nastavení pro Syncthing: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="733"/>
        <source>Unable to request Syncthing config: </source>
        <translation>Nedaří se vyžádat si nastavení Syncthing: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="864"/>
        <source>Unable to parse Syncthing status: </source>
        <translation>Nedaří se zpracovat stav Syncthing: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="883"/>
        <source>Unable to request Syncthing status: </source>
        <translation>Nedaří se vyžádat si stav Syncthing: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="931"/>
        <source>Unable to parse connections: </source>
        <translation>Chyba při zpracování spojení: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1014"/>
        <source>Unable to request connections: </source>
        <translation>Nedaří se vyžádat si spojení: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1125"/>
        <source>Unable to parse folder statistics: </source>
        <translation>Nedaří se zpracovat statistiky adresáře: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1176"/>
        <location filename="../syncthingconnection_requests.cpp" line="1238"/>
        <source>Unable to request folder statistics: </source>
        <translation>Nedaří se vyžádat si statistiky adresáře: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1413"/>
        <source>Unable to parse device statistics: </source>
        <translation>Nedaří se zpracovat statistiky zařízení: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1440"/>
        <source>Unable to request device statistics: </source>
        <translation>Nedaří se vyžádat si statitiky zařízení: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1053"/>
        <source>Unable to parse errors: </source>
        <translation>Nedaří se zpracovat chyby: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1093"/>
        <source>Unable to request errors: </source>
        <translation>Nedaří se vyžádat si chyby: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="682"/>
        <source>Unable to request clearing errors: </source>
        <translation>Nedaří se vyžádat si vyčištění chyb: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2210"/>
        <source>Unable to parse Syncthing events: </source>
        <translation>Nedaří se zpracovat události v Syncthing: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2253"/>
        <source>Unable to request Syncthing events: </source>
        <translation>Nedaří se vyžádat si události v Syncthing: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1992"/>
        <source>Unable to post config: </source>
        <translation>Nedaří se odeslat nové nastavení: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="587"/>
        <source>Unable to request rescan: </source>
        <translation>Nedaří se vyžádat si opětovné prohledání: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="422"/>
        <source>Unable to request device pause/resume: </source>
        <translation>Nedaří se vyžádat si pozastavení/pokračování zařízení: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="526"/>
        <source>Unable to request folder pause/resume: </source>
        <translation>Nedaří se vyžádat si pozastavení/pokračování adresáře: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="618"/>
        <source>Unable to request restart: </source>
        <translation>Nedaří se vyžádat si restart: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="647"/>
        <source>Unable to request shutdown: </source>
        <translation>Nedaří se vyžádat si vypnutí: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1219"/>
        <source>Unable to parse status for folder %1: </source>
        <translation>Nedaří se zpracovat stav adresáře %1: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1286"/>
        <source>Unable to parse pull errors for folder %1: </source>
        <translation>Nedaří se zpracovat chyby příjmu pro adresář %1: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1300"/>
        <source>Unable to request pull errors for folder %1: </source>
        <translation>Nedaří se vyžádat si chyby pro adresář %1: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1366"/>
        <source>Unable to parse completion for device/folder %1/%2: </source>
        <translation>Nedaří se zpracovat stupeň dokončení pro zařízení/adresář %1/%2: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1381"/>
        <source>Unable to request completion for device/folder %1/%2: </source>
        <translation>Nedaří se vyžádat si stupeň dokončení pro zařízení/složku %1/%2: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1468"/>
        <source>Unable to parse version: </source>
        <translation>Nedaří se zpracovat verzi: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1482"/>
        <source>Unable to request version: </source>
        <translation>Nedaří se vyžádat si verzi: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1600"/>
        <source>Unable to request directory override: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1633"/>
        <source>Unable to request directory revert: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1805"/>
        <source>Unable to parse JSON response: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1818"/>
        <source>Unable to request: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1843"/>
        <source>Unable to parse response for browsing &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1857"/>
        <source>Unable to browse &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1881"/>
        <location filename="../syncthingconnection_requests.cpp" line="1905"/>
        <source>Unable to query ignore patterns of &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1931"/>
        <source>Unable to change ignore patterns of &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2852"/>
        <source>Unable to parse disk events: </source>
        <translation>Nedaří se zpracovat události úložiště: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2877"/>
        <source>Unable to request disk events: </source>
        <translation>Nedaří se vyžádat si události úložiště: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1235"/>
        <source>at offset %1</source>
        <translation>na posunu %1</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.h" line="704"/>
        <source>connecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.h" line="706"/>
        <source>, re-connect attempt every %1 ms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingNotifier</name>
    <message>
        <location filename="../syncthingnotifier.cpp" line="82"/>
        <source>Device %1 (%2) wants to connect.</source>
        <translation>Zařízení %1 (%2) se chce připojit.</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="96"/>
        <source>Device </source>
        <translation>Zařízení </translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="96"/>
        <source>Unknown device </source>
        <translation>Neznámé zařízení </translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="98"/>
        <source> wants to share folder %1.</source>
        <translation> chce sdílet adresář %1.</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="100"/>
        <source> wants to share folder %1 (%2).</source>
        <translation> chce sdílet složku %1 (%2).</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="115"/>
        <source>Failed to start Syncthing</source>
        <translation>Nepodařilo se spustit Syncthing</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="116"/>
        <source>Maybe the configured binary path is wrong or the binary is not marked as executable.</source>
        <translation>Možná je nastaven nesprávný popis umístění spustitelného souboru nebo tento není označen jako spustitelný.</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="119"/>
        <source>Syncthing crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syncthing crashed with exit code %1</source>
        <translation type="vanished">Syncthing zhavarovalo s návratovým kódem %1</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="122"/>
        <source>Syncthing launcher error occurred</source>
        <translation>Došlo k chybě ve spouštěči Syncthing</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingService</name>
    <message>
        <location filename="../syncthingservice.cpp" line="378"/>
        <source>start unit</source>
        <translation>spustit jednotku</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="380"/>
        <source>stop unit</source>
        <translation>zastavit jednotku</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="395"/>
        <source>enable unit</source>
        <translation>zapnout jednotku</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="397"/>
        <source>disable unit</source>
        <translation>vypnout jednotku</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="407"/>
        <source>reload all unit files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::Utils</name>
    <message>
        <location filename="../utils.cpp" line="40"/>
        <source>%1 ago</source>
        <translation>před %1</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="43"/>
        <source>right now</source>
        <translation>právě teď</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="54"/>
        <source>unknown</source>
        <translation>neznámé</translation>
    </message>
    <message numerus="yes">
        <location filename="../utils.cpp" line="70"/>
        <source>%1 file(s)</source>
        <translation>
            <numerusform>%1 soubor</numerusform>
            <numerusform>%1 soubory</numerusform>
            <numerusform>%1 souborů</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../utils.cpp" line="71"/>
        <source>%1 dir(s)</source>
        <translation>
            <numerusform>%1 adr.</numerusform>
            <numerusform>%1 adr.</numerusform>
            <numerusform>%1 adr.</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="86"/>
        <source>Synchronization of local folder %1 complete</source>
        <translation>Synchronizace místního adresáře %1 dokončena</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="94"/>
        <source>Synchronization of the following local folders complete:
</source>
        <translation>Synchronizace následujících místních adresářů dokončena:
</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="108"/>
        <source>file system watcher and periodic rescan disabled</source>
        <translation>sledování souborového systému a periodické skenování vypnuto</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="110"/>
        <source>file system watcher active, periodic rescan disabled</source>
        <translation>sledování souborového systému zapnuto, periodické skenování vypnuto</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="113"/>
        <source>, file system watcher enabled</source>
        <translation>, sledování souborového systému zapnuto</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="114"/>
        <source>, file system watcher disabled</source>
        <translation>, sledování souborového systému vypnuto</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="89"/>
        <source>Synchronization of %1 on %2 complete</source>
        <translation>Synchronizace %1 na %2 dokončena</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="97"/>
        <source>Synchronization of the following folders on %1 complete:
</source>
        <translation>Synchronizace následujících adresářů na %1 dokončena:
</translation>
    </message>
</context>
<context>
    <name>SyncthingDev</name>
    <message>
        <source>paused</source>
        <translation type="vanished">pozastaveno</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="36"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="39"/>
        <source>Syncing (%1 %, %2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncthingDevStatus</name>
    <message>
        <source>unknown</source>
        <translation type="vanished">neznámé</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation type="vanished">odpojeno</translation>
    </message>
    <message>
        <source>this device</source>
        <translation type="vanished">vlastní zařízení</translation>
    </message>
    <message>
        <source>idle</source>
        <translation type="vanished">nečinné</translation>
    </message>
    <message>
        <source>synchronizing</source>
        <translation type="vanished">synchronizuje se</translation>
    </message>
    <message>
        <source>out of sync</source>
        <translation type="vanished">nesesynchronizováno</translation>
    </message>
    <message>
        <source>rejected</source>
        <translation type="vanished">odmítnuto</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="15"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="17"/>
        <source>Disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="19"/>
        <source>This Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="21"/>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="23"/>
        <source>Syncing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="25"/>
        <source>Out of Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="27"/>
        <source>Rejected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncthingDir</name>
    <message>
        <source>paused</source>
        <translation type="vanished">pozastaveno</translation>
    </message>
    <message>
        <source>unshared</source>
        <translation type="vanished">nesdíleno</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="180"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="183"/>
        <source>Unshared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="18"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="195"/>
        <source>Local Additions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="197"/>
        <source>Unexpected Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="20"/>
        <source>Up to Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="22"/>
        <source>Waiting to Scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="205"/>
        <source>Scanning (%1 %, %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="209"/>
        <source>Scanning (%1 %)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="214"/>
        <source>Syncing (%1 %, %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="24"/>
        <source>Scanning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="26"/>
        <source>Waiting to Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="28"/>
        <source>Preparing to Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="30"/>
        <source>Syncing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="32"/>
        <source>Cleaning Versions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="34"/>
        <source>Waiting to Clean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="36"/>
        <source>Out of Sync</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncthingDirStatus</name>
    <message>
        <source>unknown</source>
        <translation type="vanished">neznámé</translation>
    </message>
    <message>
        <source>idle</source>
        <translation type="vanished">nečinné</translation>
    </message>
    <message>
        <source>scanning</source>
        <translation type="vanished">skenuje se</translation>
    </message>
    <message>
        <source>synchronizing</source>
        <translation type="vanished">synchronizuje se</translation>
    </message>
    <message>
        <source>out of sync</source>
        <translation type="vanished">nesesynchronizováno</translation>
    </message>
</context>
<context>
    <name>SyncthingDirType</name>
    <message>
        <source>unknown</source>
        <translation type="vanished">neznámé</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="45"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="47"/>
        <source>Send &amp; Receive</source>
        <translation>Odesílat a přijímat</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="49"/>
        <source>Send Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="51"/>
        <source>Receive Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="53"/>
        <source>Receive Encrypted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send only</source>
        <translation type="vanished">Pouze odesílat</translation>
    </message>
    <message>
        <source>Receive only</source>
        <translation type="vanished">Pouze přijímat</translation>
    </message>
</context>
</TS>
